Examples Gallery
================

This is a gallery of examples, most of which were translated from the original
`egg-smol rust examples <https://github.com/mwillsey/egg-smol/tree/08a6e8fecdb77e6ba72a1b1d9ff4aff33229912c/tests>`_.
